<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://www.dcsdigital.co.uk
 * @since      1.0.0
 *
 * @package    Dcs_Digital_Guides
 * @subpackage Dcs_Digital_Guides/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Dcs_Digital_Guides
 * @subpackage Dcs_Digital_Guides/admin
 * @author     DCS Digital <support@dcsdigital.co.uk>
 */
class Dcs_Digital_Guides_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Dcs_Digital_Guides_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Dcs_Digital_Guides_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/dcs-digital-guides-admin.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Dcs_Digital_Guides_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Dcs_Digital_Guides_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/dcs-digital-guides-admin.js', array( 'jquery' ), $this->version, false );

	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function admin_footer() {

		?>
		<div class="dcs_guide_callout"><svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-video"><polygon points="23 7 16 12 23 17 23 7"></polygon><rect x="1" y="5" width="15" height="14" rx="2" ry="2"></rect></svg> Watch guide</div>
		
		<div id="dcs_guide_modal">
			<h1 class="dcs_guide_title"></h1>
			<div class="dcs_guide_content"></div>
			<div class="dcs_guide_video"></div>
			<div class="dcs_guide_help">
				<a href="mailto:support@dcsdigital.co.uk" class="dcs_guide_btn_link">Get help</a>
				<a href="https://www.dcsdigital.co.uk" target="_blank" class="dcs_guide_logo"><svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" xmlns:serif="http://www.serif.com/" width="100%" height="100%" viewBox="0 0 717 158" version="1.1" xml:space="preserve" style="fill-rule:evenodd;clip-rule:evenodd;stroke-linejoin:round;stroke-miterlimit:2;"> <g transform="matrix(1,0,0,1,-279.759,-29.735)"> <g transform="matrix(1.72689,0,0,1.72689,-5068.91,-1362.1)"> <path d="M3201.88,826.902C3211.08,826.99 3220.01,831.087 3226.09,838.045L3226.89,838.968L3216.06,848.332C3210.17,841.726 3199.89,838.768 3191.64,844.259C3179.32,852.456 3179.41,876.203 3195.43,881.935C3202.19,884.354 3210.07,882.482 3215.22,876.839L3216.06,875.903L3226.89,885.267C3218.1,895.449 3203.3,900.232 3190.24,895.317C3171.39,888.226 3162.43,862.096 3173.36,843.376C3179.02,833.689 3189.66,827.132 3201.08,826.905C3201.35,826.902 3201.62,826.901 3201.88,826.902ZM3255.95,826.902C3265.83,827.012 3276.24,831.59 3279.75,841.361L3280.14,842.497L3266.7,847.317C3263.76,839.883 3251.72,839.265 3246.3,844.592C3245.47,845.41 3244.83,846.512 3244.99,847.674C3245.42,850.853 3249.03,852.054 3251.68,852.717C3251.68,852.717 3254.58,853.453 3257.11,853.885L3261.78,854.642C3272.06,856.567 3282.11,863.97 3282.62,874.711C3283.46,892.096 3256.94,904.495 3238.63,892.482C3234.49,889.767 3231.14,885.827 3229.59,881.103L3229.22,879.913L3243.01,875.804C3245.67,885.241 3262.79,885.507 3267.61,877.846C3269.35,875.092 3266.32,871.681 3263.86,870.362C3261.99,869.354 3259.15,868.709 3259.15,868.709C3256.01,868.17 3252.9,867.36 3249.74,866.962C3249.74,866.962 3233.91,863.136 3231.08,851.375C3228.21,839.423 3239.98,827.23 3255.04,826.907C3255.34,826.902 3255.64,826.901 3255.95,826.902ZM3163.39,896.2L3149.04,896.2L3149.04,891.336C3148.88,891.459 3148.71,891.579 3148.54,891.699C3133.93,901.89 3111.56,897.375 3101.93,880.426C3094.2,866.826 3096.21,848.084 3107.24,836.729C3117.73,825.918 3135.89,823.491 3148.95,832.957L3149.04,805.98L3163.39,805.98L3163.39,896.2ZM3130.22,841.252C3122.14,841.35 3114.74,847.439 3112.47,855.54C3108.91,868.253 3117.27,885.494 3133.58,882.721C3147.33,880.383 3154.57,859.416 3143.66,847.236C3140.29,843.479 3135.37,841.232 3130.22,841.252Z" style="fill:rgb(22,21,24);fill-rule:nonzero;"></path> </g> <g transform="matrix(1.88706,0,0,2.09596,-5487.64,-2964.4)"> <rect x="3252.64" y="1445.76" width="3.639" height="57.971" style="fill:rgb(22,21,24);"></rect> </g> <g transform="matrix(2.81464,0,0,2.81464,-8540.84,-3892.38)"> <g transform="matrix(40,0,0,40,3282.6,1438.48)"> <path d="M0.269,0.01C0.197,0.01 0.144,-0.013 0.11,-0.061C0.075,-0.108 0.057,-0.165 0.055,-0.232L0.054,-0.26L0.055,-0.288C0.057,-0.355 0.075,-0.413 0.11,-0.46C0.144,-0.507 0.197,-0.53 0.269,-0.53C0.342,-0.53 0.398,-0.504 0.437,-0.451L0.437,-0.688C0.437,-0.695 0.439,-0.7 0.443,-0.704C0.447,-0.708 0.452,-0.71 0.459,-0.71L0.476,-0.71C0.483,-0.71 0.488,-0.708 0.492,-0.704C0.496,-0.7 0.498,-0.695 0.498,-0.688L0.498,-0.022C0.498,-0.015 0.496,-0.01 0.492,-0.006C0.488,-0.002 0.483,0 0.476,0L0.459,0C0.452,0 0.447,-0.002 0.443,-0.006C0.439,-0.01 0.437,-0.015 0.437,-0.022L0.437,-0.069C0.398,-0.016 0.342,0.01 0.269,0.01ZM0.275,-0.048C0.328,-0.048 0.367,-0.066 0.394,-0.101C0.421,-0.135 0.435,-0.177 0.437,-0.224C0.438,-0.231 0.438,-0.244 0.438,-0.263C0.438,-0.282 0.438,-0.295 0.437,-0.302C0.436,-0.331 0.43,-0.358 0.418,-0.384C0.406,-0.409 0.388,-0.43 0.364,-0.447C0.34,-0.464 0.31,-0.472 0.275,-0.472C0.221,-0.472 0.182,-0.455 0.157,-0.421C0.132,-0.386 0.118,-0.342 0.116,-0.288L0.115,-0.26C0.115,-0.198 0.127,-0.147 0.151,-0.108C0.175,-0.068 0.216,-0.048 0.275,-0.048Z" style="fill:rgb(22,21,24);fill-rule:nonzero;"></path> </g> <g transform="matrix(40,0,0,40,3305.8,1438.48)"> <path d="M0.092,-0.627C0.085,-0.627 0.08,-0.629 0.076,-0.633C0.072,-0.637 0.07,-0.642 0.07,-0.649L0.07,-0.687C0.07,-0.694 0.072,-0.699 0.076,-0.704C0.08,-0.708 0.085,-0.71 0.092,-0.71L0.13,-0.71C0.137,-0.71 0.142,-0.708 0.147,-0.704C0.151,-0.699 0.153,-0.694 0.153,-0.687L0.153,-0.649C0.153,-0.642 0.151,-0.637 0.147,-0.633C0.142,-0.629 0.137,-0.627 0.13,-0.627L0.092,-0.627ZM0.103,0C0.096,0 0.091,-0.002 0.087,-0.006C0.083,-0.01 0.081,-0.015 0.081,-0.022L0.081,-0.498C0.081,-0.505 0.083,-0.51 0.087,-0.514C0.091,-0.518 0.096,-0.52 0.103,-0.52L0.12,-0.52C0.127,-0.52 0.132,-0.518 0.136,-0.514C0.14,-0.51 0.142,-0.505 0.142,-0.498L0.142,-0.022C0.142,-0.015 0.14,-0.01 0.136,-0.006C0.132,-0.002 0.127,0 0.12,0L0.103,0Z" style="fill:rgb(22,21,24);fill-rule:nonzero;"></path> </g> <g transform="matrix(40,0,0,40,3314.72,1438.48)"> <path d="M0.275,0.22C0.223,0.22 0.181,0.211 0.15,0.193C0.119,0.175 0.097,0.155 0.085,0.132C0.072,0.109 0.066,0.088 0.066,0.071C0.066,0.065 0.068,0.06 0.073,0.056C0.077,0.052 0.082,0.05 0.088,0.05L0.102,0.05C0.108,0.05 0.113,0.051 0.117,0.055C0.12,0.058 0.123,0.063 0.126,0.071C0.147,0.132 0.195,0.162 0.27,0.162C0.327,0.162 0.37,0.15 0.397,0.127C0.424,0.103 0.438,0.061 0.438,0L0.438,-0.069C0.399,-0.016 0.343,0.01 0.27,0.01C0.198,0.01 0.145,-0.013 0.111,-0.061C0.076,-0.108 0.058,-0.165 0.056,-0.232L0.055,-0.26L0.056,-0.288C0.058,-0.355 0.076,-0.413 0.111,-0.46C0.145,-0.507 0.198,-0.53 0.27,-0.53C0.343,-0.53 0.399,-0.504 0.438,-0.451L0.438,-0.497C0.438,-0.504 0.44,-0.509 0.444,-0.514C0.448,-0.518 0.453,-0.52 0.46,-0.52L0.476,-0.52C0.483,-0.52 0.488,-0.518 0.493,-0.514C0.497,-0.509 0.499,-0.504 0.499,-0.497L0.499,-0.01C0.499,0.061 0.482,0.118 0.449,0.159C0.416,0.2 0.358,0.22 0.275,0.22ZM0.276,-0.048C0.329,-0.048 0.368,-0.066 0.395,-0.101C0.422,-0.135 0.436,-0.177 0.438,-0.224C0.439,-0.231 0.439,-0.243 0.439,-0.26C0.439,-0.277 0.439,-0.289 0.438,-0.296C0.436,-0.343 0.422,-0.385 0.395,-0.42C0.368,-0.455 0.329,-0.472 0.276,-0.472C0.222,-0.472 0.183,-0.455 0.158,-0.421C0.132,-0.386 0.119,-0.342 0.117,-0.288L0.116,-0.26L0.117,-0.232C0.119,-0.178 0.132,-0.134 0.158,-0.1C0.183,-0.065 0.222,-0.048 0.276,-0.048Z" style="fill:rgb(22,21,24);fill-rule:nonzero;"></path> </g> <g transform="matrix(40,0,0,40,3337.96,1438.48)"> <path d="M0.092,-0.627C0.085,-0.627 0.08,-0.629 0.076,-0.633C0.072,-0.637 0.07,-0.642 0.07,-0.649L0.07,-0.687C0.07,-0.694 0.072,-0.699 0.076,-0.704C0.08,-0.708 0.085,-0.71 0.092,-0.71L0.13,-0.71C0.137,-0.71 0.142,-0.708 0.147,-0.704C0.151,-0.699 0.153,-0.694 0.153,-0.687L0.153,-0.649C0.153,-0.642 0.151,-0.637 0.147,-0.633C0.142,-0.629 0.137,-0.627 0.13,-0.627L0.092,-0.627ZM0.103,0C0.096,0 0.091,-0.002 0.087,-0.006C0.083,-0.01 0.081,-0.015 0.081,-0.022L0.081,-0.498C0.081,-0.505 0.083,-0.51 0.087,-0.514C0.091,-0.518 0.096,-0.52 0.103,-0.52L0.12,-0.52C0.127,-0.52 0.132,-0.518 0.136,-0.514C0.14,-0.51 0.142,-0.505 0.142,-0.498L0.142,-0.022C0.142,-0.015 0.14,-0.01 0.136,-0.006C0.132,-0.002 0.127,0 0.12,0L0.103,0Z" style="fill:rgb(22,21,24);fill-rule:nonzero;"></path> </g> <g transform="matrix(40,0,0,40,3346.88,1438.48)"> <path d="M0.256,0C0.207,0 0.172,-0.015 0.151,-0.045C0.13,-0.074 0.12,-0.115 0.12,-0.167L0.12,-0.462L0.042,-0.462C0.035,-0.462 0.03,-0.464 0.026,-0.468C0.022,-0.472 0.02,-0.477 0.02,-0.484L0.02,-0.498C0.02,-0.505 0.022,-0.51 0.026,-0.514C0.03,-0.518 0.035,-0.52 0.042,-0.52L0.12,-0.52L0.12,-0.688C0.12,-0.695 0.122,-0.7 0.126,-0.704C0.13,-0.708 0.135,-0.71 0.142,-0.71L0.159,-0.71C0.166,-0.71 0.171,-0.708 0.175,-0.704C0.179,-0.7 0.181,-0.695 0.181,-0.688L0.181,-0.52L0.305,-0.52C0.312,-0.52 0.317,-0.518 0.321,-0.514C0.325,-0.51 0.327,-0.505 0.327,-0.498L0.327,-0.484C0.327,-0.477 0.325,-0.472 0.321,-0.468C0.317,-0.464 0.312,-0.462 0.305,-0.462L0.181,-0.462L0.181,-0.171C0.181,-0.134 0.187,-0.106 0.2,-0.087C0.212,-0.068 0.232,-0.058 0.261,-0.058L0.315,-0.058C0.322,-0.058 0.327,-0.056 0.331,-0.052C0.335,-0.048 0.337,-0.043 0.337,-0.036L0.337,-0.022C0.337,-0.015 0.335,-0.01 0.331,-0.006C0.327,-0.002 0.322,0 0.315,0L0.256,0Z" style="fill:rgb(22,21,24);fill-rule:nonzero;"></path> </g> <g transform="matrix(40,0,0,40,3361.24,1438.48)"> <path d="M0.221,0.01C0.189,0.01 0.159,0.003 0.132,-0.01C0.105,-0.023 0.083,-0.041 0.067,-0.064C0.05,-0.087 0.042,-0.112 0.042,-0.139C0.042,-0.183 0.06,-0.219 0.096,-0.247C0.131,-0.275 0.179,-0.293 0.24,-0.301L0.398,-0.323L0.398,-0.358C0.398,-0.395 0.387,-0.423 0.365,-0.443C0.342,-0.462 0.308,-0.472 0.262,-0.472C0.228,-0.472 0.2,-0.465 0.179,-0.452C0.157,-0.439 0.143,-0.423 0.137,-0.404C0.134,-0.396 0.131,-0.391 0.128,-0.388C0.124,-0.385 0.119,-0.383 0.113,-0.383L0.099,-0.383C0.093,-0.383 0.088,-0.385 0.084,-0.39C0.079,-0.394 0.077,-0.399 0.077,-0.405C0.077,-0.42 0.084,-0.437 0.097,-0.457C0.11,-0.476 0.131,-0.493 0.159,-0.508C0.187,-0.523 0.221,-0.53 0.262,-0.53C0.333,-0.53 0.384,-0.513 0.414,-0.479C0.444,-0.445 0.459,-0.404 0.459,-0.355L0.459,-0.022C0.459,-0.015 0.457,-0.01 0.453,-0.006C0.449,-0.002 0.444,0 0.437,0L0.42,0C0.413,0 0.408,-0.002 0.404,-0.006C0.4,-0.01 0.398,-0.015 0.398,-0.022L0.398,-0.069C0.383,-0.047 0.362,-0.028 0.334,-0.013C0.305,0.002 0.268,0.01 0.221,0.01ZM0.231,-0.048C0.28,-0.048 0.32,-0.064 0.351,-0.096C0.382,-0.128 0.398,-0.174 0.398,-0.234L0.398,-0.268L0.269,-0.25C0.214,-0.243 0.173,-0.23 0.145,-0.212C0.117,-0.194 0.103,-0.171 0.103,-0.144C0.103,-0.113 0.116,-0.09 0.142,-0.073C0.167,-0.056 0.197,-0.048 0.231,-0.048Z" style="fill:rgb(22,21,24);fill-rule:nonzero;"></path> </g> <g transform="matrix(40,0,0,40,3382.68,1438.48)"> <path d="M0.104,0C0.097,0 0.092,-0.002 0.088,-0.006C0.084,-0.01 0.082,-0.015 0.082,-0.022L0.082,-0.688C0.082,-0.695 0.084,-0.7 0.088,-0.704C0.092,-0.708 0.097,-0.71 0.104,-0.71L0.121,-0.71C0.128,-0.71 0.133,-0.708 0.137,-0.704C0.141,-0.7 0.143,-0.695 0.143,-0.688L0.143,-0.022C0.143,-0.015 0.141,-0.01 0.137,-0.006C0.133,-0.002 0.128,0 0.121,0L0.104,0Z" style="fill:rgb(22,21,24);fill-rule:nonzero;"></path> </g> </g> </g> </svg> </a>
			</div>
			<div id="dcs_guide_close"><svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-x"><line x1="18" y1="6" x2="6" y2="18"></line><line x1="6" y1="6" x2="18" y2="18"></line></svg></div>
		</div>
		<?php

	}

	// disable default dashboard widgets
	public function register_meta_boxes() {

		// Add DCS Welcome widget
		add_meta_box( 
			'dcs-guides',
			__( ' ', 'dcs-digital-guides' ),
			[ $this, 'render_example_widget' ],
			'dashboard',
			'normal',  // $context: 'advanced', 'normal', 'side', 'column3', 'column4'
			'high',     // $priority: 'high', 'core', 'default', 'low'
		);

	}

	/**
	 * Render widget.
	 */
	public function render_example_widget() {
		include_once 'partials/dashboard/dcs-welcome-widget.php';
	}

}
