(function( $ ) {
	'use strict';

	/**
	 * All of the code for your admin-facing JavaScript source
	 * should reside in this file.
	 *
	 * Note: It has been assumed you will write jQuery code here, so the
	 * $ function reference has been prepared for usage within the scope
	 * of this function.
	 *
	 * This enables you to define handlers, for when the DOM is ready:
	 *
	 * $(function() {
	 *
	 * });
	 *
	 * When the window is loaded:
	 *
	 * $( window ).load(function() {
	 *
	 * });
	 *
	 * ...and/or other possibilities.
	 *
	 * Ideally, it is not considered best practise to attach more than a
	 * single DOM-ready or window-load handler for a particular page.
	 * Although scripts in the WordPress core, Plugins and Themes may be
	 * practising this, we should strive to set a better example in our own work.
	 */

	 $( window ).load(function() {

		let path = location.pathname;
		let urlParams = JSON.stringify(Object.fromEntries(new URLSearchParams(location.search)));

		// This query is handled by the "DCS Digital Build Customisations" plugin on the "Build" system
		jQuery.ajax({
			url: 'https://build.dcsdigital.co.uk/wp-json/wp/v2/guides/?path=' + path + '&parameters=' + urlParams,
			method: 'GET',
			success: function(data) {

				jQuery.each(data, function(key, guide) {

					let source_url = guide.link;
					let video_url = guide.meta['youtube-url'];
					let title = guide.title.rendered;

					jQuery('.dcs_guide_callout').show().css('display', 'flex');

					jQuery(".dcs_guide_callout").click(function() {

						// We're checking if the content container is empty before updating the HTML
						// because people might hide and show the video as they're following the tutorial
						// and we don't want the video to stop playing
						if(document.querySelector('.dcs_guide_content:empty')) {
							jQuery('.dcs_guide_content').html('<object style="width: 100%;" width="100%" height="500" data="' + video_url + '" frameborder="0"></object>');
						}

						jQuery('.dcs_guide_title').html(title);

						jQuery('#dcs_guide_modal').css('visibility', 'visible');
					});

					jQuery("#dcs_guide_close").click(function() {
						jQuery('#dcs_guide_modal').css('visibility', 'hidden');
					});
 
				});

			}
		});



	 });

})( jQuery );
