<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://www.dcsdigital.co.uk
 * @since             1.0.0
 * @package           Dcs_Digital_Guides
 *
 * @wordpress-plugin
 * Plugin Name:       Guides for WordPress and Woocommerce
 * Plugin URI:        https://www.dcsdigital.co.uk
 * Description:       Provides contextual video tutorials and guides for WordPress, Woocommerce and popular plugins.
 * Version:           1.0.0
 * Author:            DCS Digital
 * Author URI:        https://www.dcsdigital.co.uk/contact
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       dcs-digital-guides
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define( 'DCS_DIGITAL_GUIDES_VERSION', '1.0.0' );
define( 'DCS_DIGITAL_GUIDES_PLUGIN_URL', plugin_dir_url( __FILE__ ) );

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-dcs-digital-guides-activator.php
 */
function activate_dcs_digital_guides() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-dcs-digital-guides-activator.php';
	Dcs_Digital_Guides_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-dcs-digital-guides-deactivator.php
 */
function deactivate_dcs_digital_guides() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-dcs-digital-guides-deactivator.php';
	Dcs_Digital_Guides_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_dcs_digital_guides' );
register_deactivation_hook( __FILE__, 'deactivate_dcs_digital_guides' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-dcs-digital-guides.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_dcs_digital_guides() {

	$plugin = new Dcs_Digital_Guides();
	$plugin->run();

}
run_dcs_digital_guides();
